yakumo.nova.v2.hypervisor

Package yakumo :: Package nova :: Package v2 :: Module hypervisor |
[hide private]
[frames] | no frames]

# Module hypervisor

source code

Resource class and its manager for hypervisors in Compute API v2

Classes | [hide private]
| Resource Resource class for hypervisors in Compute API v2
| Manager Manager class for hypervisors in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('hostname', 'hypervisor_hostname', mapper
      .Noop), ('type', 'hypervisor_type', mapper.Noop), ('version', 'hypervi
      sor_version', mapper.Noop), ('cpu_info', 'cpu_info', mapper.Noop), ('w
      orkload', 'current_workload', mapper.Noop), ('disk_available_least', '
      disk_available_least', mapper.Noop), ('free_disk_gb', 'free_disk_gb',
      mapper.Noop), ('free_ram_mb', 'free_ram_mb', mapper.Noop), ('local_gb'
      , 'local_gb', mapper.Noop), ('local_gb_used', 'local_gb_used', mapper.
      Noop), ('memory_mb', 'memory_mb', mapper.Noop), ('memory_mb_used', 'me
      ...